Package: BiocPkgTools
Type: Package
Title: Collection of simple tools for learning about Bioconductor
        Packages
Version: 1.30.0
Date: 2026-03-13
Authors@R: c( 
    person("Shian", "Su", role=c("aut", "ctb"), email = "su.s@wehi.edu.au"),
    person("Lori", "Shepherd", role="ctb", email = "Lori.Shepherd@roswellpark.org"),
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", c("aut", "ctb"),
      c(ORCID = "0000-0002-3242-0582")),
    person("Felix G.M.", "Ernst", role="ctb", email = "felix.gm.ernst@outlook.com"),
    person("Jennifer","Wokaty", role="ctb", email="jennifer.wokaty@gmail.com"),
    person("Charlotte", "Soneson", role="ctb", email = "charlottesoneson@gmail.com"),
    person("Martin", "Morgan", role="ctb", email = "martin.morgan@roswellpark.org"),
    person("Vince", "Carey", role="ctb", email="stvjc@channing.harvard.edu"),
    person("Sean", "Davis", email = "seandavi@gmail.com",role = c("aut", "cre"))
    )
Description: Bioconductor has a rich ecosystem of metadata around
        packages, usage, and build status. This package is a simple
        collection of functions to access that metadata from R. The
        goal is to expose metadata for data mining and value-added
        functionality such as package searching, text mining, and
        analytics on packages.
Depends: htmlwidgets, R (>= 4.1.0)
Imports: BiocFileCache, BiocManager, biocViews, tibble, methods, rlang,
        stringr, stats, rvest, dplyr, xml2, readr, httr, httr2,
        htmltools, DT, tools, utils, igraph (>= 2.0.0), jsonlite, gh,
        RBGL, graph, curl, glue, lubridate, purrr, tidyr, yaml
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, testthat, tm, networkD3,
        visNetwork, clipr, blastula, kableExtra, DiagrammeR,
        SummarizedExperiment
License: MIT + file LICENSE
BugReports: https://github.com/seandavi/BiocPkgTools/issues/new
URL: https://github.com/seandavi/BiocPkgTools
Encoding: UTF-8
RoxygenNote: 7.3.3
Roxygen: list(markdown = TRUE)
SystemRequirements: mailsend-go
biocViews: Software, Infrastructure
Config/pak/sysreqs: cmake git libglpk-dev make libicu-dev libuv1-dev
        libxml2-dev libssl-dev libx11-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:48:41 UTC
RemoteUrl: https://github.com/bioc/BiocPkgTools
RemoteRef: RELEASE_3_23
RemoteSha: 9b3d701c47cee85923a1d8e60bfe12ca1cf83453
NeedsCompilation: no
Packaged: 2026-04-29 16:24:25 UTC; root
Author: Shian Su [aut, ctb],
  Lori Shepherd [ctb],
  Marcel Ramos [aut, ctb] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  Felix G.M. Ernst [ctb],
  Jennifer Wokaty [ctb],
  Charlotte Soneson [ctb],
  Martin Morgan [ctb],
  Vince Carey [ctb],
  Sean Davis [aut, cre]
Maintainer: Sean Davis <seandavi@gmail.com>
Built: R 4.6.0; ; 2026-04-29 16:26:41 UTC; unix
