# Generated by roxygen2: do not edit by hand

S3method(print,repositoryStats)
S3method(summary,biocrevdeps)
export(CRANstatus)
export(activitySince)
export(anacondaDownloadStats)
export(biocBuildEmail)
export(biocBuildReport)
export(biocBuildReportDB)
export(biocBuildStatusDB)
export(biocDownloadStats)
export(biocExplore)
export(biocMaintained)
export(biocPkgList)
export(biocPkgRanges)
export(biocRevDepEmail)
export(biocVIEWSdb)
export(buildClassDepData)
export(buildClassDepFromPackage)
export(buildClassDepGraph)
export(buildPkgDependencyDataFrame)
export(buildPkgDependencyIgraph)
export(firstInBioc)
export(getBiocVignette)
export(getPackageInfo)
export(getPkgYearsInBioc)
export(get_bioc_data)
export(get_cre_orcids)
export(githubDetails)
export(githubURLParts)
export(hasBiocMaint)
export(inducedSubgraphByPkgs)
export(latestPkgStats)
export(orcid_table)
export(pkgBiocDeps)
export(pkgBiocRevDeps)
export(pkgCombDependencyGain)
export(pkgDepImports)
export(pkgDepMetrics)
export(pkgDownloadRank)
export(pkgDownloadStats)
export(pkgToolsCache)
export(plotClassDep)
export(plotClassDepData)
export(plotClassDepGraph)
export(problemPage)
export(repositoryStats)
export(sentHistory)
export(setCache)
export(subgraphByDegree)
export(templatePath)
import(biocViews)
import(tools)
import(utils)
import(xml2)
importFrom(BiocFileCache,BiocFileCache)
importFrom(BiocFileCache,bfcdownload)
importFrom(BiocFileCache,bfcneedsupdate)
importFrom(BiocFileCache,bfcnew)
importFrom(BiocFileCache,bfcquery)
importFrom(BiocFileCache,bfcrpath)
importFrom(BiocFileCache,bfcupdate)
importFrom(BiocManager,containerRepository)
importFrom(BiocManager,repositories)
importFrom(BiocManager,version)
importFrom(DT,datatable)
importFrom(RBGL,transitive.closure)
importFrom(curl,curl)
importFrom(curl,has_internet)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,collect)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(dplyr,top_n)
importFrom(gh,gh)
importFrom(glue,glue)
importFrom(grDevices,extendrange)
importFrom(graph,edges)
importFrom(graph,nodes)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(htmltools,a)
importFrom(htmlwidgets,createWidget)
importFrom(httr,HEAD)
importFrom(httr,POST)
importFrom(httr,PUT)
importFrom(httr,VERB)
importFrom(httr,accept)
importFrom(httr,add_headers)
importFrom(httr,authenticate)
importFrom(httr,content)
importFrom(httr,content_type)
importFrom(httr,headers)
importFrom(httr,message_for_status)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(httr2,oauth_client)
importFrom(httr2,oauth_flow_client_credentials)
importFrom(httr2,obfuscated)
importFrom(httr2,req_auth_bearer_token)
importFrom(httr2,req_body_form)
importFrom(httr2,req_headers)
importFrom(httr2,req_method)
importFrom(httr2,req_options)
importFrom(httr2,req_perform)
importFrom(httr2,req_template)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,degree)
importFrom(igraph,delete_edges)
importFrom(igraph,delete_vertices)
importFrom(igraph,distances)
importFrom(igraph,edge_attr)
importFrom(igraph,ego)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,induced_subgraph)
importFrom(igraph,is_igraph)
importFrom(igraph,layout_with_kk)
importFrom(igraph,subcomponent)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(lubridate,mdy)
importFrom(methods,getClass)
importFrom(methods,is)
importFrom(purrr,list_rbind)
importFrom(purrr,map2)
importFrom(readr,read_lines)
importFrom(rlang,is_call)
importFrom(rlang,is_pairlist)
importFrom(rlang,is_symbol)
importFrom(rlang,is_syntactic_literal)
importFrom(rvest,html_nodes)
importFrom(rvest,html_table)
importFrom(rvest,html_text)
importFrom(rvest,html_text2)
importFrom(stats,setNames)
importFrom(stringr,str_match)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_squish)
importFrom(stringr,str_to_upper)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,tibble)
importFrom(tidyr,unnest_longer)
importFrom(utils,available.packages)
importFrom(utils,combn)
importFrom(utils,download.file)
importFrom(utils,read.table)
importFrom(xml2,read_html)
importFrom(yaml,read_yaml)
