---
title: "%s CRAN Package Report"
date: "%s"
output:
  BiocStyle::html_document:
    toc: false
    number_sections: false
---

## Package: %s

---

Please be advised that the `%s` CRAN package has at least one
error in the build results. Please see the status table below:

```{r echo = FALSE, results='asis', out.width="\\maxwidth"}
kableExtra::kable_styling(
    knitr::kable(%s, caption = "CRAN Build Report",
        align = "l", escape = FALSE
    ),
    bootstrap_options = c("hover", "striped", "responsive"),
    full_width = FALSE
)
```

%s

---
